@@ -15,11 +15,11 @@ use List::Util   1.29 qw/ pairs /;
 use Module::Load qw/ load /;
 use Net::IP::LPM;
 use Plack::Util;
-use Plack::Util::Accessor qw/ default_rate rules cache file _match greylist retry_after /;
+use Plack::Util::Accessor qw/ default_rate rules cache file _match greylist retry_after init_file /;
 use Ref::Util             qw/ is_plain_arrayref /;
 use Time::Seconds         qw/ ONE_MINUTE /;
 
-our $VERSION = 'v0.5.3'; # TRIAL
+our $VERSION = 'v0.5.4'; # TRIAL
 
 
 sub prepare_app {
@@ -33,6 +33,8 @@ sub prepare_app {
     die "retry_after must be a positive integer greater than ${ \ONE_MINUTE} seconds"
       unless $self->retry_after =~ /^[1-9][0-9]*$/ && $self->retry_after > ONE_MINUTE;
 
+    $self->init_file(0) unless defined $self->init_file;
+
     unless ( $self->cache ) {
 
         my $file = $self->file // die "No cache was set";
@@ -41,7 +43,8 @@ sub prepare_app {
 
         my $cache = Cache::FastMmap->new(
             share_file  => "$file",
-            init_file   => 1,
+            init_file   => $self->init_file,
+            unlink_on_exit => !$self->init_file,
             serializer  => '',
             expire_time => ONE_MINUTE,
         );
@@ -172,7 +175,7 @@ Plack::Middleware::Greylist - throttle requests with different rates based on ne
 
 =head1 VERSION
 
-version v0.5.3
+version v0.5.4
 
 =head1 SYNOPSIS
 
@@ -228,6 +231,8 @@ This sets the C<Retry-After> header value, in seconds. It defaults to 61 seconds
 Note that this does not enforce that a client has waited that amount of time before making a new request, as long as the
 number of hits per minute is within the allowed rate.
 
+This option was added in v0.2.0
+
 =head2 greylist
 
 This is a hash reference to the greylist configuration.
@@ -276,6 +281,13 @@ This is the path of the throttle count file used by the L</cache>.
 
 It is required unless you are defining your own L</cache>.
 
+=head2 init_file
+
+This is boolean that configures whether L</file> will be re-initialised in startup. Unless you are preloading the
+application before forking, this should be false (default).
+
+This option was added in v0.5.4.
+
 =head2 cache
 
 This is a code reference to a function that increments the cache counter for a key (usually the IP address or net
